@@ -1,6 +1,6 @@
 target.arrival.hdf <-
 function(xdata, ydata, date, t, rts = "crs",
-                               wd = NULL, sg = "ssm", ftype = "d", cv = "convex"){
+                               wd = NULL, sg = "ssm", ftype = "d", cv = "convex", anc = FALSE){
   
   # Initial checks
   if(t <= min(date))                                   stop('t is earlier than dataset.')
@@ -21,11 +21,13 @@ function(xdata, ydata, date, t, rts = "crs",
   rts   <- ifelse(cv == "fdh", "vrs", rts)
   r     <- tail(which(sort(date) <= t), 1)
   id_f  <- which(date > t)
+  org   <- unique(sort(date)[1:r])[-1]
   
   # Data frames
   eff_t       <- array(NA, c(n, 1))
   lambda      <- array(NA, c(n, n))
   ed          <- array(NA, c(n, 1))
+  roc_anc     <- array(NA, c(n, 1))
   roc_ind     <- array(NA, c(n, 1))
   arrival_avg <- array(NA, c(n, 1))
   arrival_seg <- array(NA, c(n, 1))
@@ -46,9 +48,25 @@ function(xdata, ydata, date, t, rts = "crs",
   ed[id_f,] <- if(ftype == "s") rep(t, n - r) else lambda[id_f, -id_f] %*% date[-id_f,] / rowSums(lambda[id_f, -id_f])
   
   # RoC
-  hdf_roc        <- roc.hdf(xdata, ydata, date, t, rts, wd, sg, ftype, cv)
-  roc_local      <- hdf_roc$roc_local
-  roc_avg        <- hdf_roc$roc_avg
+  
+  if(anc == T){
+    for(i in org){
+      origin  <- i
+      roc_t   <- roc.hdf(xdata, ydata, date, t, rts, wd, sg, ftype, cv)
+      roc_anc <- cbind(roc_anc, roc_t$roc_local)
+    }
+    roc_anc   <- roc_anc[, -1, drop = F] # For coding convenience, could be improved
+    id_lroc   <- which(!is.na(roc_anc[, length(org)]))
+    roc_prmr  <- matrix(apply(roc_anc[id_lroc,, drop = F], 1, 
+                              function(x) ifelse(all(is.na(x)), NA, x[which(!is.na(x))[1]])), ncol = 1)
+    roc_local <- array(NA, c(n, 1))
+    roc_prmr  -> roc_local[id_lroc,]
+    roc_avg   <- mean(roc_anc[, dim(roc_anc)[2]], na.rm = T)
+  }else{
+    roc_t     <- roc.hdf(xdata, ydata, date, t, rts, wd, sg, ftype, cv)
+    roc_local <- roc_t$roc_local
+    roc_avg   <- roc_t$roc_avg
+  }
   id_lroc        <- which(!is.na(roc_local))
   roc_ind[id_f,] <- lambda[id_f, id_lroc, drop = F] %*% roc_local[id_lroc,] / rowSums(lambda[id_f, id_lroc, drop = F])
 
@@ -59,7 +77,7 @@ function(xdata, ydata, date, t, rts = "crs",
   arrival_seg[id_eff,] <- ed[id_eff,] + log(eff_t[id_eff,], exp(1)) / log(roc_ind[id_eff,], exp(1))
   
   results <- list(eff_t = eff_t, lambda_t = lambda, eft_date = ed, 
-                  roc_avg = roc_avg, roc_local = roc_local, roc_ind = roc_ind, 
+                  roc_avg = roc_avg, roc_anc = roc_anc, roc_local = roc_local, roc_ind = roc_ind, 
                   arrival_avg = arrival_avg, arrival_seg = arrival_seg)
   return(results)    
 }
